200 myplot A1 0 1000 TRUE PI ADD 1 1 AND TRUE EQ hello Parameter Reading TEXT Enter Input 0 1 20 WHILE TRUE i 1 10 1 j BREAK item small string much longer string 0 ADD 1 1 ROOT 9 SIN 45 EVEN 0 ROUND 3.1 SUM 64 10 1 100 SPLIT , GET FROM_START list SET FROM_START list NUMERIC 1 30 A1 PV1 WG IN2 IN2 0 2 OD1 IN2 4 2 IN2 4 2 SQ1 10 10 A1 100 1 A1 100 2 A1 200 5 A1 500 5 A1 500 5 [118]BMP280 1 1 0 CS1 0 0 0 0 0 0 0 0 0 1 START 500 5 25 A1 -17.905 35.5 WG PV1 200 C

Missing Hardware! Is a device Connected?

Title
Help
Sample Programs Menu